@@ -56,8 +56,7 @@ def kdb(
 ):
 
     if version:
-        print(f"kube-debug-pod {_version}")
-        print(image)
+        print(f"kube-debug-pod v{_version}")
         exit(0)
 
     # set image
@@ -97,10 +96,6 @@ def kdb(
         shell=True,
     )
 
-    if return_code not in [1, 0]:
-        print(f"failed to attach to pod {pod_name} in {namespace} namespace")
-        exit(return_code)
-
     # delete pod
     return_code = call(f"kubectl delete pod {pod_name} -n {namespace}", shell=True)
     if return_code != 0:
